emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

emacs-29 637f5b164f 2/2: ; Add "src" to the heuristic sub-directory heur


From: Philip Kaludercic
Subject: emacs-29 637f5b164f 2/2: ; Add "src" to the heuristic sub-directory heuristic
Date: Tue, 27 Dec 2022 15:24:01 -0500 (EST)

branch: emacs-29
commit 637f5b164f2dedad45bff6d881231a8f014c65bc
Author: Philip Kaludercic <philipk@posteo.net>
Commit: Philip Kaludercic <philipk@posteo.net>

    ; Add "src" to the heuristic sub-directory heuristic
    
    * lisp/emacs-lisp/package-vc.el (package-vc--unpack): Check for "src"
    directories, next to "lisp".
---
 lisp/emacs-lisp/package-vc.el | 27 +++++++++++++++------------
 1 file changed, 15 insertions(+), 12 deletions(-)

diff --git a/lisp/emacs-lisp/package-vc.el b/lisp/emacs-lisp/package-vc.el
index b01f87d049..a9fbdfea21 100644
--- a/lisp/emacs-lisp/package-vc.el
+++ b/lisp/emacs-lisp/package-vc.el
@@ -613,18 +613,21 @@ checkout.  This overrides the `:branch' attribute in 
PKG-SPEC."
 
     ;; When nothing is specified about a `lisp-dir', then should
     ;; heuristically check if there is a sub-directory with lisp
-    ;; files.  These are conventionally just called "lisp".  If this
-    ;; directory exists and contains non-zero number of lisp files, we
-    ;; will use that instead of `pkg-dir'.
-    (when-let* (((null lisp-dir))
-                (dir (expand-file-name "lisp" pkg-dir))
-                ((file-directory-p dir))
-                ((directory-files dir nil "\\`[^.].+\\.el\\'" t 1)))
-      ;; We won't use `dir', since dir is an absolute path and we
-      ;; don't want `lisp-dir' to depend on the current location of
-      ;; the package installation, ie. to break if moved around the
-      ;; file system or between installations.
-      (setq lisp-dir "lisp"))
+    ;; files.  These are conventionally just called "lisp" or "src".
+    ;; If this directory exists and contains non-zero number of lisp
+    ;; files, we will use that instead of `pkg-dir'.
+    (catch 'done
+      (dolist (name '("lisp" "src"))
+        (when-let* (((null lisp-dir))
+                    (dir (expand-file-name name pkg-dir))
+                    ((file-directory-p dir))
+                    ((directory-files dir nil "\\`[^.].+\\.el\\'" t 1)))
+          ;; We won't use `dir', since dir is an absolute path and we
+          ;; don't want `lisp-dir' to depend on the current location of
+          ;; the package installation, ie. to break if moved around the
+          ;; file system or between installations.
+          (throw 'done (setq lisp-dir name)))))
+
     (when lisp-dir
       (push (cons :lisp-dir lisp-dir)
             (package-desc-extras pkg-desc)))



reply via email to

[Prev in Thread] Current Thread [Next in Thread]